California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 54 - CLASSIFICATION BY RACE, ETHNICITY, COLOR OR NATIONAL ORIGIN. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1258137 | BUSTAMANTE COMMITTEE AGAINST PROP. 54, THE CRUZ | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1256562 | STOP 54 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1237969 | YES ON PROPOSITION 54 / RACIAL PRIVACY INITIATIVE SPONSORED BY AMERICAN CIVIL RIGHTS COALITION | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1257450 | ASIAN AMERICAN FAMILIES AGAINST PROP 54 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
950500 | CALIFORNIANS FOR JUSTICE / NO ON 54 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1256083 | SANTA CLARA COUNTY COALITION FOR AN INFORMED CALIFORNIA | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1258103 | COMMITTEE TO KEEP THE DREAM ALIVE - VOTE NO ON PROPOSITION 54 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1258000 | SAN FRANCISCANS AGAINST PROP. 54 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1258109 | SACRAMENTO COUNTY DEMOCRATS OPPOSED TO THE RECALL | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1258110 | SAN DIEGO COALITION FOR AN INFORMED CALIFORNIA, COMMITTEE AGAINST PROPOSITION 54 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1244492 | NO ON 54: TEACHERS, WORKERS, HEALTHCARE, CIVIL LIBERTIES & ENTERTAINMENT GROUPS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1256875 | CALIFORNIANS TO STOP THE CON! NO ON THE RECALL & NO ON PROP. 54 (SPONSORED BY NEIGHBOR TO NEIGHBOR) | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1258807 | SACRAMENTO REGIONAL AFRICAN AMERICAN COALITION, SRAAC | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1257764 | VAMOS ADELANTE - NO ON PROP. 54 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1257645 | UNITED SACRAMENTO CITIZENS AGAINST THE INFORMATION BAN | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1257912 | NAACP NATIONAL VOTER FUND - NO ON PROP. 54 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1276681 | AMERICAN CIVIL RIGHTS COALITION COMMITTEE | SUPPORT